@@ -1,6 +1,6 @@
 #' Read an Epi Info file with a .rec file extension.
 #'
-#' This function will load all of the data sets stored in the specified 
+#' This function will load all of the data sets stored in the specified
 #' Epi Info file into the global environment.
 #'
 #' @param data.file The name of the data file to be read.
@@ -15,9 +15,9 @@
 #' \dontrun{epiinfo.reader('example.rec', 'data/example.rec', 'example')}
 epiinfo.reader <- function(data.file, filename, variable.name)
 {
-  require.package('foreign')
+  .require.package('foreign')
 
   assign(variable.name,
-         read.epiinfo(filename),
+         foreign::read.epiinfo(filename),
          envir = .TargetEnv)
 }
