@@ -28,7 +28,7 @@ tsv.reader <- function(data.file, filename, variable.name)
 
   assign(variable.name,
          read.csv(filename,
-                  header = TRUE,
+                  header = config$data_loading_header,
                   sep = '\t'),
          envir = .TargetEnv)
 }
